/*
 * Copyright 2014 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.deculture.sh;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.util.Collection;
import java.util.Collections;

import net.morilib.sh.AbstractShFileSystem;
import net.morilib.sh.DefaultShVirtualDirectory;
import net.morilib.sh.ShEnvironment;
import net.morilib.sh.ShFile;
import net.morilib.sh.ShProcess;
import net.morilib.sh.ShSecurityPolicy;
import net.morilib.sh.ShStat;

/**
 * 
 *
 *
 * @author MORIGUCHI, Yuichiro 2014/01/15
 */
public class DecultureFileSystem extends AbstractShFileSystem {

	private static class StF implements ShFile {

		private byte[] buf;
		private String name;

		StF(String name, String f) {
			this.name = name;
			this.buf  = f.getBytes();
		}

		@Override
		public boolean isDirectory() {
			return false;
		}

		@Override
		public boolean isExecutable() {
			return false;
		}

		@Override
		public boolean isExist() {
			return true;
		}

		@Override
		public boolean isFile() {
			return true;
		}

		@Override
		public boolean isReadable() {
			return true;
		}

		@Override
		public boolean isWritable() {
			return false;
		}

		@Override
		public boolean isHidden() {
			return false;
		}

		@Override
		public boolean isZeroFile() {
			return buf.length == 0;
		}

		@Override
		public long getLastModified() {
			return 0;
		}

		@Override
		public String getName() {
			return name;
		}

		@Override
		public Collection<ShFile> getFiles() {
			return Collections.emptySet();
		}

		@Override
		public InputStream getInputStream() throws IOException {
			return new ByteArrayInputStream(buf);
		}

		@Override
		public PrintStream getPrintStream(
				boolean append) throws IOException {
			return null;
		}

		@Override
		public ShProcess getProcess() {
			return null;
		}

		@Override
		public ShFile toAbsolute() {
			return this;
		}

		@Override
		public ShFile toCanonical() {
			return this;
		}

		@Override
		public boolean mkdir() {
			return false;
		}

		@Override
		public boolean renameTo(ShFile f) {
			return false;
		}

		@Override
		public void setLastModified(long time) {
			// do nothing
		}

		@Override
		public boolean rmdir() {
			return false;
		}

		@Override
		public boolean deleteFile() {
			return false;
		}

		@Override
		public ShStat getStat() {
			return new ShStat(toString(), 0, buf.length,
					ShStat.READABLE);
		}

		@Override
		public String toString() {
			return name;
		}

	}

	private DefaultShVirtualDirectory root;
	private ShFile fragmentFile, definitionFile;

	/**
	 * 
	 * @param d
	 * @param in
	 */
	public DecultureFileSystem(String d, String in) {
		root = new DefaultShVirtualDirectory(null, null);

		fragmentFile = new StF("fragment", in);
		root.addFile(fragmentFile);

		definitionFile = new StF("definition", d);
		root.addFile(definitionFile);
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getRoot()
	 */
	@Override
	public ShFile getRoot() {
		return root;
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getFile(java.lang.String)
	 */
	@Override
	public ShFile getFile(String s) {
		if(s.equals("/")) {
			return root;
		} else if(s.equals("fragment")) {
			return fragmentFile;
		} else if(s.equals("definition")) {
			return definitionFile;
		} else {
			return null;
		}
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getFile(java.lang.String, java.lang.String)
	 */
	@Override
	public ShFile getFile(String dir, String name) {
		return getFile(getFile(dir), name);
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getFile(net.morilib.sh.ShFile, java.lang.String)
	 */
	@Override
	public ShFile getFile(ShFile dir, String name) {
		return null;
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getNativeFile(java.lang.String)
	 */
	@Override
	public ShFile getNativeFile(String s) {
		return getFile(s);
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getSecurityPolicy()
	 */
	@Override
	public ShSecurityPolicy getSecurityPolicy() {
		return ShSecurityPolicy.ALL_PERMITTED;
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getProfile()
	 */
	@Override
	public InputStream getProfile() {
		return null;
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getRc()
	 */
	@Override
	public InputStream getRc() {
		return null;
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#getHome()
	 */
	@Override
	public ShFile getHome() {
		return getRoot();
	}

	/* (non-Javadoc)
	 * @see net.morilib.sh.ShFileSystem#searchPath(net.morilib.sh.ShEnvironment, java.lang.String)
	 */
	@Override
	public ShFile searchPath(ShEnvironment env, String name) {
		return null;
	}

}
